@@ -1,7 +1,7 @@
 #!/bin/sh
 echo 'name: blaze-builder-enumerator
-version: 0.2.0.4
-id: blaze-builder-enumerator-0.2.0.4-084ae88fa2f45a7cf6c98461d286584d
+version: 0.2.0.5
+id: blaze-builder-enumerator-0.2.0.5-f74fee72f8b84d91962e5e4025680b57
 
 license: BSD3
 copyright: Copyright (c) 2010, 2011 Simon Meier
@@ -23,23 +23,23 @@ exposed: True
 exposed-modules: Blaze.ByteString.Builder.Enumerator
 hidden-modules:
 trusted: False
-import-dirs: /usr/local/lib/ghc/blaze-builder-enumerator-0.2.0.4
-library-dirs: /usr/local/lib/ghc/blaze-builder-enumerator-0.2.0.4
-hs-libraries: HSblaze-builder-enumerator-0.2.0.4
+import-dirs: /usr/local/lib/ghc/blaze-builder-enumerator-0.2.0.5
+library-dirs: /usr/local/lib/ghc/blaze-builder-enumerator-0.2.0.5
+hs-libraries: HSblaze-builder-enumerator-0.2.0.5
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: base-4.5.1.0-5b1c9d3d412ed227632edae6d2aca151
-         blaze-builder-0.2.1.4-cbacb369ecb80a55dd55bab68eb21ee1
-         bytestring-0.9.2.1-3c5b69d9d36e3a0179d120b97025ab86
-         enumerator-0.4.19-54652fc37c21c9ff6bc4aced898d00e5
-         transformers-0.3.0.0-2889ebed7e61112cda7ded5e4c153bcf
+depends: base-4.6.0.1-6b06c3defb20732cfd08deb8ba52ca7c
+         blaze-builder-0.3.1.1-71a2ae53eb5daf9e6673db8b47b3b6b5
+         bytestring-0.10.0.2-1c6ab0cabcb254a0e55d751d8ef17b51
+         enumerator-0.4.19-13fa8f89bd8effdb12c1bcec44c8658a
+         transformers-0.3.0.0-ff2bb6ac67241ebb987351a3db564af0
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-blaze-builder-enumerator-0.2.0.4/html/blaze-builder-enumerator.haddock
-haddock-html: /usr/local/share/doc/hs-blaze-builder-enumerator-0.2.0.4/html
-' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
+haddock-interfaces: /usr/local/share/doc/hs-blaze-builder-enumerator-0.2.0.5/html/blaze-builder-enumerator.haddock
+haddock-html: /usr/local/share/doc/hs-blaze-builder-enumerator-0.2.0.5/html
+' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
